<template>
    <section class="popOverlay" v-bind:class="{ active: $parent.showLoginModal }">
        <div class="modalOverlay">
            <div class="logoWrap">
                <img :src="this.$parent.path+'frontend/images/logo-white.png'" alt="logo" width="339" height="60">
            </div>
            <div class="or">or</div>
            <div class="loginWithFB"></div>
            <b-form @submit="onSubmit" @reset="onReset">
                <b-input-group>
                    <b-input-group-prepend>
                        <b-button aria-label="user icon button"><i class="fa fa-user"></i><i class="d-none">0</i></b-button>
                    </b-input-group-prepend>

                    <b-form-input
                            id="input-1"
                            v-model="form.email"
                            type="email"
                            aria-label="Email"
                            required
                            placeholder="Email"
                    ></b-form-input>
                </b-input-group>
                <b-input-group>
                    <b-input-group-prepend>
                        <b-button aria-label="icon pass button"><i class="icon-pass"></i><i class="d-none">0</i></b-button>
                    </b-input-group-prepend>

                    <b-form-input
                            id="input-2"
                            v-model="form.password"
                            type="password"
                            aria-label="Password"
                            required
                            placeholder="Enter Password"
                    ></b-form-input>
                </b-input-group>

                <b-buttonn aria-label="Login button" type="submit" class="btnMre btn-lg">Login</b-buttonn>

            </b-form>
            <div class="bottomText">
                <a href="/password/reset">I Forgot My Password ?</a>
                <a href="/register/student">Student Registration</a>
            </div>
            <div class="cross">
                <a href="javascript:void(0);" v-on:click="this.$parent.loginPopup" class="close_new_login"><i
                        class="fa fa-times"></i> <i class="d-none">0</i></a>
            </div>
        </div>
    </section>
</template>

<script>
    module.exports = {
        props:['path'],
        data() {
            return {
                form: {
                    email: '',
                    password: '',
                },

            }
        },
        methods: {
            onSubmit(evt) {
                evt.preventDefault()

                const formData = this.form;
                axios.post('/ajaxLogin', formData).then(response => {
                    console.log(response)
                    window.location.reload()

                })

            },
            onReset(evt) {
                evt.preventDefault()
                // Reset our form values
                this.form.email = ''
                this.form.password = ''
                // Trick to reset/clear native browser form validation state
                this.show = false
                this.$nextTick(() => {
                    this.show = true
                })
            }
        }
    };
</script>

<style scoped>

    .cross {
        position: absolute;
        top: 10px;
        right: 15px;

    }

    .cross a {
        color: #fff;
        font-size: 18px;
    }

    .or {
        color: #fff;
        text-transform: uppercase;
        margin: .5em 0 1em;
    }

    .logoWrap {
        margin-bottom: 1em;
    }

    .bottomText a {
        color: #fff;
        display: block;
        margin: 0 auto;
        text-align: center
    }

    .icon-pass {
        margin: 0;
        padding: 0;
        width: 24px;
        height: 24px;
        display: block;
        background: url(../assets/images/pass.png) center center no-repeat;
    }

    .popOverlay {
        margin: 0;
        padding: 0;
        position: fixed;
        width: 100%;
        height: 100%;
        background: rgba(51, 51, 51, .98);
        z-index: -99;
        top: 0;
        left: 0;
        right: 0;
        bottom: 0;
        opacity: 0;
        transition: all ease 0.4s;
    }

    .popOverlay.active {
        opacity: 1;
        z-index: 9999;
    }

    .modalOverlay {
        height: 100%;
        display: flex;
        align-items: center;
        justify-content: center;
        width: 530px;
        margin: 0 auto;
        flex-direction: column;
        padding: 0 15px;
        max-width: 100%;
    }

    .modalOverlay form {
        width: 100%;
    }

    .modalOverlay form .input-group {
        margin-bottom: 15px;
    }

    .modalOverlay form .input-group .btn-secondary {
        color: #555;
        background: transparent;
        border: 0;
        padding: 0;
    }

    .modalOverlay form .input-group input {
        height: 58px;
    }

    .modalOverlay form .input-group input:focus {
        outline: none
    }

    .modalOverlay form .input-group .input-group-prepend {
        padding: 6px 12px;
        font-size: 14px;
        font-weight: 400;
        line-height: 1;
        color: #555;
        text-align: center;
        background-color: #eee;
        border: 1px solid #ccc;
        border-top-left-radius: 4px;
        border-bottom-left-radius: 4px;
        width: 50px;
        text-align: center;
        justify-content: center;
    }

    .favouritBox {
        border: 4px solid #ccc;
        border-radius: 8px;
        -moz-border-radius: 8px;
        -webkit-border-radius: 8px;
        padding: 8px;
        overflow: hidden;
        margin-bottom: 15px;
        cursor: pointer;
        display: flex;
        position: relative;
    }

    .favouritBox:hover {
        border: 4px solid #24CE61;
    }

    .favouritBox .campusThumb {
        border-radius: 8px;
        -moz-border-radius: 8px;
        -webkit-border-radius: 8px;
        padding: 8px;
    }

    .favouritBox .campusShortDes {
        margin-left: 15px;
        width: 100%;
    }

    .campusShortDes .price a {
        color: #24ce61;
        text-decoration: none;
        font-size: 12px;
    }

    .campusShortDes .price p {
        font-size: 12px;
    }

    .rt-amount {
        margin: 0 20px 0 0;
        float: left;
        font-size: 12px;
    }

    .campusShareBrn {
        display: flex;
        width: 100%;
        justify-content: space-between;
        padding-top: 10px;
    }

    .campusShareBrn ul {
        padding: 0;
        list-style: none;
        font-size: 12px;
        margin-bottom: 5px;
    }

    .favouritBox > .campusThumb > a > img {
        width: 120px;
        height: 100px;
    }

    .btnMre {
        display: inline-block;
        padding: 6px 12px;
        margin-bottom: 0;
        line-height: 1.428571429;
        text-align: center;
        white-space: nowrap;
        vertical-align: middle;
        cursor: pointer;
        border: 1px solid transparent;
        border-radius: 4px;
        -webkit-user-select: none;
        -moz-user-select: none;
        -ms-user-select: none;
        -o-user-select: none;
        user-select: none;
        color: #fff;
        background-color: #5cb85c;
        text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.2);
        -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.15),
        0 1px 1px rgba(0, 0, 0, 0.075);
        box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.15),
        0 1px 1px rgba(0, 0, 0, 0.075);
        background-image: -webkit-linear-gradient(top, #24ce61 0, #00ab3d 100%);
        background-image: linear-gradient(to bottom, #24ce61 0, #00ab3d 100%);
        background-repeat: repeat-x;
        border-color: #00ab3d;
        filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff5cb85c', endColorstr='#ff419641', GradientType=0);
        filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
        font-size: 12px;
        font-weight: bold;
    }

    .btn-lg {
        padding: 10px 16px;
        font-size: 18px;
        line-height: 1.33;
        border-radius: 6px;
        width: 100%;
        font-weight: 400;
    }

    .card {
        max-width: 970px;
        margin: 0 auto;
    }

    .pattern-bg {
        padding: 30px 0;
        min-height: calc(100vh - 70px);
    }

    .header-dark .card-body {
        padding: 0;
    }

    .header-dark .card-title {
        background: #333;
        color: #fff;
        font-size: 1.75rem;
        padding: 10px 30px;
        margin-bottom: 0;
    }

    .campusNews {
        padding: 10px 15px;
    }

    .campusNews .card-text {
        font-size: 0.875rem;
    }

    .campusNews .newsList {
        list-style: none;
        padding: 0;
        margin: 20px 0 0;
    }

    .campusNews .newsList li {
        display: flex;
        align-items: center;
        padding: 10px 0;
    }

    .campusNews .newsList li .newsImg {
        height: 10rem;
        border: 1px solid #9c9c9c;
        padding: 10px;
        text-align: center;
    }

    .campusNews .newsList li .newsImg img {
        width: 100%;
        height: 100%;
        object-fit: cover;
    }

    .campusNews .newsList li .newsDesc h2 {
        color: #23ce60;
    }

    .campusNews .newsList li .newsDesc h2 a {
        color: inherit;
        text-decoration: none;
    }

    .campusNews .newsList li .newsDesc h2:hover {
        color: #18a048;
    }

    .campusNews .newsList li .newsDesc p {
        font-size: 0.9rem;
    }

    .tagline {
        font-size: 15px;
        border-bottom: 1px solid #ccc;
        padding: 0 0 8px;
        color: #7d7d7d;
        margin-bottom: 10px;
        margin-top: 0;
        text-transform: uppercase;
    }

    .ShareButton {
        background: url(../assets/images/2.gif);
        background-size: 230px auto;
        width: 230px;
        display: inline-block;
        cursor: pointer;
        height: 40px;
    }

    .shar_wrap {
        text-align: center;
    }
    .btn-close{width: 15px;height: 15px;font-size: 15px;color: #23ce60;background: transparent;box-shadow: none;border: 0;position: absolute;padding: 0;z-index: 9;right: 5px;top: 5px;}

    @media (min-width: 767px) {


        .campusNews .newsList li .newsDesc {
            padding-left: 20px;
        }

        .campusNews .newsList li .newsImg {
            width: 13rem;
        }

        .campusNews .newsList li .newsDesc h2 {
            font-size: 1.5rem;
        }
    }

    @media (max-width: 767px) {
        .campusNews .newsList li {
            flex-wrap: wrap;
        }

        .campusNews .newsList li .newsImg {
            width: 10rem;
            margin: 0 auto 10px;
        }

        .campusNews .newsList li .newsDesc h2 {
            font-size: 1.25rem;
        }
    }
</style>
